==> pdfadd_2.0.orig.tar.gz: pdfadd-2.0/arbredialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ARBREDIALOG_H
#define ARBREDIALOG_H

#include "ui_arbredialog.h"
#include "pdfviewer.h"

#include <QProcess>
#include <QPointer>
#include <QCloseEvent>
#include <QTreeWidgetItem>
#include <QDomDocument>
#include <QDomElement>
#include <QDomNode>
#include <QDomNodeList>
#include <QProgressDialog>

class ArbreDialog : public QDialog  {
   Q_OBJECT
public:
	ArbreDialog(QWidget *parent=0);
	~ArbreDialog();
	Ui::ArbreDialog ui;
QString pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier, preambuleAsy;
int compteur_noeuds;
private :
QString tempDir,asyTempFile,pdfTempFile,prefixFile;
QString asyMessage;
QPointer<QProcess> asy_pdf_proc;
bool estModifie, erreurProcessus;
QPointer<PdfViewer> pdfviewerWindow;
QPointer<QProgressDialog> progressDialog;
QStringList itemMacros;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();

void AjouterBranche();
void SupprimerBranche();
void AjouterSousBranche();
void ActualiserArbre();
void ActualiserCode(const QString &text);

QString GenererCode();
QString CodeNoeud(QTreeWidgetItem *parentItem,QTreeWidgetItem *item, bool haut);
void AfficherCode();
void NettoyerCode();

void NouvelArbre();
void ItemVersXml(QTreeWidgetItem *item,QDomDocument doc ,QDomElement parent);
void SauverArbre();
void XmlVersItem(QTreeWidgetItem *parentItem, QDomElement element);
void ChargerArbre();

void AsyPdfTemp();
void finAsyPdfProcess(int err);
void VoirTemp();
void readInfoOutput();

void Aide();

void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
void AjouterMacro(int item);
signals:
void asy_pdf_fini();
};
#endif

==> pdfadd_2.0.1.orig.tar.gz: pdfadd-2.0.1/arbredialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/pdfadd/                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/

#ifndef ARBREDIALOG_H
#define ARBREDIALOG_H

#include "ui_arbredialog.h"
#include "pdfviewer.h"
#include "cmdlauncher.h"


#include <QPointer>
#include <QCloseEvent>
#include <QTreeWidgetItem>
#include <QDomDocument>
#include <QDomElement>
#include <QDomNode>
#include <QDomNodeList>

class ArbreDialog : public QDialog  {
   Q_OBJECT
public:
	ArbreDialog(QWidget *parent=0);
	~ArbreDialog();
	Ui::ArbreDialog ui;
QString extraPath, pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier, preambuleAsy;
int compteur_noeuds;
private :
QString tempDir,asyTempFile,pdfTempFile,prefixFile;
QPointer<CmdLauncher> asy_pdf_proc;
bool estModifie, erreurProcessus;
QPointer<PdfViewer> pdfviewerWindow;
QStringList itemMacros;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();

void AjouterBranche();
void SupprimerBranche();
void AjouterSousBranche();
void ActualiserArbre();
void ActualiserCode(const QString &text);

QString GenererCode();
QString CodeNoeud(QTreeWidgetItem *parentItem,QTreeWidgetItem *item, bool haut);
void AfficherCode();
void NettoyerCode();

void NouvelArbre();
void ItemVersXml(QTreeWidgetItem *item,QDomDocument doc ,QDomElement parent);
void SauverArbre();
void XmlVersItem(QTreeWidgetItem *parentItem, QDomElement element);
void ChargerArbre();

void AsyPdfTemp();
void VoirTemp();
void ErreurCompilation();

void Aide();

void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
void AjouterMacro(int item);

signals:
void asy_pdf_fini();
};
#endif
